/*
 * dlgcrang.c --- copy range dialog
 * 
 * Copyright (c) 2019 Mariano Alvarez Fernandez (malfer@telefonica.net)
 *
 * This file is part of FEdit, a visual font editor for the MGRX font format
 *
 * FEdit is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * FEdit is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with FEdit. If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdlib.h>
#include <stdio.h>
#include <string.h>
#include <grgui.h>
#include <mgrxcolr.h>
#include "fedit.h"

#define COMMAND_OK           1
#define COMMAND_CANCEL       2

static GUIDialog *crangdlg = NULL;
static GUIGroup *cranggo = NULL;

static int process_crangdlg_event(void *udata, GrEvent *ev)
{
    GUIDialog *d = (GUIDialog *)udata;
    GUIGroup *go = (GUIGroup *)(d->exdata);

    if (ev->type == GREV_COMMAND) {
        switch (ev->p1) {
            case COMMAND_OK :
                d->result = 1;
               return -1;
            case COMMAND_CANCEL :
                d->result = -1;
                return -1;
        }
    }

    return GUIGroupProcessEvent(go, ev);
}

int CRangDlgCreate(void)
{
    if (crangdlg) return 1; // dialog already created

    cranggo = GUIGroupCreate(8, 0, 0);
    if (cranggo == NULL) return 0;
    GUIObjectSetLabel(&(cranggo->o[0]), 0,   0,   0, 160, 30, GrNOCOLOR, WEBC_WHITE, "First source glyph");
    GUIObjectSetEntry(&(cranggo->o[1]), 1, 160,   0, 160, 30, WEBC_WHITE, WEBC_BLACK, 8, "");
    GUIObjectSetLabel(&(cranggo->o[2]), 2,   0,  40, 160, 30, GrNOCOLOR, WEBC_WHITE, "Last source glyph");
    GUIObjectSetEntry(&(cranggo->o[3]), 3, 160,  40, 160, 30, WEBC_WHITE, WEBC_BLACK, 8, "");
    GUIObjectSetLabel(&(cranggo->o[4]), 4,   0,  80, 160, 30, GrNOCOLOR, WEBC_WHITE, "First dest glyph");
    GUIObjectSetEntry(&(cranggo->o[5]), 5, 160,  80, 160, 30, WEBC_WHITE, WEBC_BLACK, 8, "");
    GUIObjectSetButton(&(cranggo->o[6]), 6,  10, 130, 140, 40, WEBC_GREEN, WEBC_WHITE, "Ok", COMMAND_OK, 0, 0);
    GUIObjectSetButton(&(cranggo->o[7]), 7, 170, 130, 140, 40, WEBC_GREEN, WEBC_WHITE, "Cancel", COMMAND_CANCEL, 0, 0);
    GUIGroupSetSelected(cranggo, 1, 0);

    crangdlg = GUIGroupDialogCreate("Copy glyphs from FLrange",
                                    cranggo, process_crangdlg_event);
    if (crangdlg == NULL) {
        GUIGroupDestroy(cranggo);
        cranggo = NULL;
        return 0;
    }

    return 1;
}

void CRangDlgDestroy(void)
{
    if (crangdlg) {
        GUIDialogDestroy(crangdlg);
        crangdlg = NULL;
    }
    if (cranggo) {
        GUIGroupDestroy(cranggo);
        cranggo = NULL;
    }
}

void CRangDlgSetData(int fsglyph, int lsglyph, int fdglyph)
{
    char s[121];
    
    if (!crangdlg) return;

    sprintf(s, "%d", fsglyph);
    GUIGroupSetText(cranggo, 1, s);
    sprintf(s, "%d", lsglyph);
    GUIGroupSetText(cranggo, 3, s);
    sprintf(s, "%d", fdglyph);
    GUIGroupSetText(cranggo, 5, s);
}

void CRangDlgGetData(int *fsglyph, int *lsglyph, int *fdglyph)
{
    char *s;

    if (!crangdlg) return;

    s = GUIGroupGetText(cranggo, 1, GrGetChrtypeForUserEncoding());
    *fsglyph = atoi(s);
    free(s);
    s = GUIGroupGetText(cranggo, 3, GrGetChrtypeForUserEncoding());
    *lsglyph = atoi(s);
    free(s);
    s = GUIGroupGetText(cranggo, 5, GrGetChrtypeForUserEncoding());
    *fdglyph = atoi(s);
    free(s);
}

int CRangDlgRun(void)
{
    if (!crangdlg) return -1; 

    crangdlg->result = -1;
    GUIDialogRun(crangdlg);
    return crangdlg->result;
}

