/*
 * dlglohef.c --- load Hershey font dialog
 * 
 * Copyright (c) 2019 Mariano Alvarez Fernandez (malfer@telefonica.net)
 *
 * This file is part of FEdit, a visual font editor for the MGRX font format
 *
 * FEdit is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * FEdit is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with FEdit. If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdlib.h>
#include <stdio.h>
#include <string.h>
#include <grgui.h>
#include <mgrxcolr.h>
#include "fedit.h"

#define COMMAND_OK           1
#define COMMAND_CANCEL       2
#define COMMAND_CF           3

static GUIDialog *flohedlg = NULL;
static GUIGroup *flohego = NULL;

static int process_flohedlg_event(void *udata, GrEvent *ev)
{
    char *s;

    GUIDialog *d = (GUIDialog *)udata;
    GUIGroup *go = (GUIGroup *)(d->exdata);

    if (ev->type == GREV_COMMAND) {
        switch (ev->p1) {
            case COMMAND_OK :
                d->result = 1;
               return -1;
            case COMMAND_CANCEL :
                d->result = -1;
                return -1;
            case COMMAND_CF :
                FileChooseDlgCreate("Choose Hershey Font File to Load", 480, 320);
                s = GUIGroupGetText(go, 1, GrGetChrtypeForUserEncoding());
                FileChooseDlgSetData(s);
                free(s);
                if (FileChooseDlgRun() == 1) {
                    s = malloc(MAXLEN_FNAME+1);
                    FileChooseDlgGetData(s);
                    GUIGroupSetText(go, 1, s);
                    GUIGroupRePaintObject(go, 1);
                    free(s);
                }
                FileChooseDlgDestroy();
                return 1;
         }
    }

    return GUIGroupProcessEvent(go, ev);
}

int FLoheDlgCreate(void)
{
    if (flohedlg) return 1; // dialog already created

    flohego = GUIGroupCreate(13, 0, 0);
    if (flohego == NULL) return 0;
    GUIObjectSetLabel(&(flohego->o[0]), 0,   0,   0,  80, 30, GrNOCOLOR, WEBC_WHITE, "File name");
    GUIObjectSetEntry(&(flohego->o[1]), 1,  80,   0, 300, 30, WEBC_WHITE, WEBC_BLACK, MAXLEN_FNAME, "");
    GUIObjectSetButton(&(flohego->o[2]), 2,380,   0,  20, 30, WEBC_WHITE, WEBC_BLACK, ".", COMMAND_CF, 0, 0);
    GUIObjectSetLabel(&(flohego->o[3]), 3,   0,  40, 160, 30, GrNOCOLOR, WEBC_WHITE, "Max glyphs to load");
    GUIObjectSetEntry(&(flohego->o[4]), 4, 160,  40, 240, 30, WEBC_WHITE, WEBC_BLACK, 8, "");
    GUIObjectSetLabel(&(flohego->o[5]), 5,   0,  80, 160, 30, GrNOCOLOR, WEBC_WHITE, "First dest. glyph");
    GUIObjectSetEntry(&(flohego->o[6]), 6, 160,  80, 240, 30, WEBC_WHITE, WEBC_BLACK, 8, "");
    GUIObjectSetLabel(&(flohego->o[7]), 7,   0, 120, 160, 30, GrNOCOLOR, WEBC_WHITE, "Zoom to apply");
    GUIObjectSetEntry(&(flohego->o[8]), 8, 160, 120, 240, 30, WEBC_WHITE, WEBC_BLACK, 16, "");
    GUIObjectSetLabel(&(flohego->o[9]), 9,   0, 160, 160, 30, GrNOCOLOR, WEBC_WHITE, "Line thick");
    GUIObjectSetEntry(&(flohego->o[10]), 10, 160, 160, 240, 30, WEBC_WHITE, WEBC_BLACK, 8, "");
    GUIObjectSetButton(&(flohego->o[11]), 11,  50, 210, 140, 40, WEBC_GREEN, WEBC_WHITE, "Ok", COMMAND_OK, 0, 0);
    GUIObjectSetButton(&(flohego->o[12]), 12, 210, 210, 140, 40, WEBC_GREEN, WEBC_WHITE, "Cancel", COMMAND_CANCEL, 0, 0);
    GUIGroupSetSelected(flohego, 1, 0);

    flohedlg = GUIGroupDialogCreate("Load Font from Hershey data",
                                    flohego, process_flohedlg_event);
    if (flohedlg == NULL) {
        GUIGroupDestroy(flohego);
        flohego = NULL;
        return 0;
    }

    return 1;
}

void FLoheDlgDestroy(void)
{
    if (flohedlg) {
        GUIDialogDestroy(flohedlg);
        flohedlg = NULL;
    }
    if (flohego) {
        GUIGroupDestroy(flohego);
        flohego = NULL;
    }
}

void FLoheDlgSetData(char *fname, int maxglyph,
                     int fdglyph, double zoom, int thick)
{
    char s[121];
    
    if (!flohedlg) return;

    GUIGroupSetText(flohego, 1, fname);
    sprintf(s, "%d", maxglyph);
    GUIGroupSetText(flohego, 4, s);
    sprintf(s, "%d", fdglyph);
    GUIGroupSetText(flohego, 6, s);
    sprintf(s, "%f", zoom);
    GUIGroupSetText(flohego, 8, s);
    sprintf(s, "%d", thick);
    GUIGroupSetText(flohego, 10, s);
}

void FLoheDlgGetData(char *fname, int *maxglyph,
                     int *fdglyph, double *zoom, int *thick)
{
    char *s;

    if (!flohedlg) return;

    s = GUIGroupGetText(flohego, 1, GrGetChrtypeForUserEncoding());
    strcpy(fname, s);
    free(s);
    s = GUIGroupGetText(flohego, 4, GrGetChrtypeForUserEncoding());
    *maxglyph = atoi(s);
    free(s);
    s = GUIGroupGetText(flohego, 6, GrGetChrtypeForUserEncoding());
    *fdglyph = atoi(s);
    free(s);
    s = GUIGroupGetText(flohego, 8, GrGetChrtypeForUserEncoding());
    *zoom = atof(s);
    free(s);
    s = GUIGroupGetText(flohego, 10, GrGetChrtypeForUserEncoding());
    *thick = atoi(s);
    free(s);
}

int FLoheDlgRun(void)
{
    if (!flohedlg) return -1; 

    flohedlg->result = -1;
    GUIDialogRun(flohedlg);
    return flohedlg->result;
}

