/*
 * dlgrsize.c --- resize font dialog
 * 
 * Copyright (c) 2019 Mariano Alvarez Fernandez (malfer@telefonica.net)
 *
 * This file is part of FEdit, a visual font editor for the MGRX font format
 *
 * FEdit is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * FEdit is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with FEdit. If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include <stdlib.h>
#include <stdio.h>
#include <string.h>
#include <grgui.h>
#include <mgrxcolr.h>
#include "fedit.h"

#define COMMAND_OK           1
#define COMMAND_CANCEL       2

static GUIDialog *rsizedlg = NULL;
static GUIGroup *rsizego = NULL;

static int process_rsizedlg_event(void *udata, GrEvent *ev)
{
    GUIDialog *d = (GUIDialog *)udata;
    GUIGroup *go = (GUIGroup *)(d->exdata);

    if (ev->type == GREV_COMMAND) {
        switch (ev->p1) {
            case COMMAND_OK :
                d->result = 1;
               return -1;
            case COMMAND_CANCEL :
                d->result = -1;
                return -1;
        }
    }

    return GUIGroupProcessEvent(go, ev);
}

int RSizeDlgCreate(void)
{
    if (rsizedlg) return 1; // dialog already created

    rsizego = GUIGroupCreate(10, 0, 0);
    if (rsizego == NULL) return 0;
    GUIObjectSetLabel(&(rsizego->o[0]), 0,   0,   0, 160, 30, GrNOCOLOR, WEBC_WHITE, "New Mean Width");
    GUIObjectSetEntry(&(rsizego->o[1]), 1, 160,   0, 160, 30, WEBC_WHITE, WEBC_BLACK, 8, "");
    GUIObjectSetLabel(&(rsizego->o[2]), 2,   0,  40, 160, 30, GrNOCOLOR, WEBC_WHITE, "New Height");
    GUIObjectSetEntry(&(rsizego->o[3]), 3, 160,  40, 160, 30, WEBC_WHITE, WEBC_BLACK, 8, "");
    GUIObjectSetLabel(&(rsizego->o[4]), 4,   0,  80, 160, 30, GrNOCOLOR, WEBC_WHITE, "First glyph");
    GUIObjectSetEntry(&(rsizego->o[5]), 5, 160,  80, 160, 30, WEBC_WHITE, WEBC_BLACK, 8, "");
    GUIObjectSetLabel(&(rsizego->o[6]), 6,   0, 120, 160, 30, GrNOCOLOR, WEBC_WHITE, "Last glyph");
    GUIObjectSetEntry(&(rsizego->o[7]), 7, 160, 120, 160, 30, WEBC_WHITE, WEBC_BLACK, 8, "");
    GUIObjectSetButton(&(rsizego->o[8]), 8,  10, 170, 140, 40, WEBC_GREEN, WEBC_WHITE, "Ok", COMMAND_OK, 0, 0);
    GUIObjectSetButton(&(rsizego->o[9]), 9, 170, 170, 140, 40, WEBC_GREEN, WEBC_WHITE, "Cancel", COMMAND_CANCEL, 0, 0);
    GUIGroupSetSelected(rsizego, 1, 0);

    rsizedlg = GUIGroupDialogCreate("Resize Font",
                                    rsizego, process_rsizedlg_event);
    if (rsizedlg == NULL) {
        GUIGroupDestroy(rsizego);
        rsizego = NULL;
        return 0;
    }

    return 1;
}

void RSizeDlgDestroy(void)
{
    if (rsizedlg) {
        GUIDialogDestroy(rsizedlg);
        rsizedlg = NULL;
    }
    if (rsizego) {
        GUIGroupDestroy(rsizego);
        rsizego = NULL;
    }
}

void RSizeDlgSetData(int nwidth, int nheight, int fglyph, int lglyph)
{
    char s[121];
    
    if (!rsizedlg) return;

    sprintf(s, "%d", nwidth);
    GUIGroupSetText(rsizego, 1, s);
    sprintf(s, "%d", nheight);
    GUIGroupSetText(rsizego, 3, s);
    sprintf(s, "%d", fglyph);
    GUIGroupSetText(rsizego, 5, s);
    sprintf(s, "%d", lglyph);
    GUIGroupSetText(rsizego, 7, s);
}

void RSizeDlgGetData(int *nwidth, int *nheight, int *fglyph, int *lglyph)
{
    char *s;

    if (!rsizedlg) return;

    s = GUIGroupGetText(rsizego, 1, GrGetChrtypeForUserEncoding());
    *nwidth = atoi(s);
    free(s);
    s = GUIGroupGetText(rsizego, 3, GrGetChrtypeForUserEncoding());
    *nheight = atoi(s);
    free(s);
    s = GUIGroupGetText(rsizego, 5, GrGetChrtypeForUserEncoding());
    *fglyph = atoi(s);
    free(s);
    s = GUIGroupGetText(rsizego, 7, GrGetChrtypeForUserEncoding());
    *lglyph = atoi(s);
    free(s);
}

int RSizeDlgRun(void)
{
    if (!rsizedlg) return -1; 

    rsizedlg->result = -1;
    GUIDialogRun(rsizedlg);
    return rsizedlg->result;
}

